# Credits

## Development Lead

Carlos Osuna <carlos.osuna@meteoswiss.ch>

## Contributors

- Petra Baumann <petra.baumann@meteoswiss.ch>
- Nina Burgdorfer <nina.burgdorfer@meteoswiss.ch>
- Victoria Cherkas <victoria.cherkas@meteoswiss.ch>
- Christian Kanesan <christian.kanesan@meteoswiss.ch>
- Tobias Wicky <tobias.wicky@meteoswiss.ch>
